server

package
v0.0.0-...-56d0f0e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2023 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DetectionEndRequest

type DetectionEndRequest struct {
	AlarmScheduleID string `json:"alarm_schedule_id"`
	UserEmail       string `json:"user_email"`
}

DetectionEndRequest is the request body for the detection end endpoint

type DetectionStartRequest

type DetectionStartRequest struct {
	AlarmScheduleID string `json:"alarm_schedule_id"`
	UserEmail       string `json:"user_email"`
}

DetectionStartRequest is the request body for the detection start endpoint

type Server

type Server struct {
	Router *chi.Mux
	// contains filtered or unexported fields
}

Server struct

func NewServer

func NewServer(temporalClient client.Client, detectionService detection.Service) *Server

NewServer creates a new Server struct

func (*Server) MountHandlers

func (s *Server) MountHandlers()

MountHandlers mounts the handlers to the router

func (*Server) Run

func (s *Server) Run(host string, port int) error

Run starts the server

Jump to