Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DetectionEndRequest ¶
type DetectionEndRequest struct {
AlarmScheduleID string `json:"alarm_schedule_id"`
UserEmail string `json:"user_email"`
}
DetectionEndRequest is the request body for the detection end endpoint
type DetectionStartRequest ¶
type DetectionStartRequest struct {
AlarmScheduleID string `json:"alarm_schedule_id"`
UserEmail string `json:"user_email"`
}
DetectionStartRequest is the request body for the detection start endpoint
Click to show internal directories.
Click to hide internal directories.